@@ -1,10 +1,7 @@
 import numpy
 import xarray
 import matplotlib.pyplot as plt
-import configparser 
-config = configparser.ConfigParser()
-config.read('lazyearth.ini')
-Cloud = (config['Cloud']['Fashcloud'])
+
 
 
 class objearth():
@@ -82,7 +79,6 @@ class objearth():
         Allpixel  = int(self.Dataset.pixel_qa.count())
         Cloudpercent = (Cpixel/Allpixel)*100
         print("Percent Cloud : %.4f"%Cloudpercent,"%")
-        print(Cloud)
 
 
 
